@@ -3,11 +3,11 @@
 """
 Mix-in class for use in multiform item class.
 
-$Id: multiformitem.py 49596 2008-01-21 10:55:31Z cray $
+$Id: multiformitem.py 51584 2008-08-31 14:51:11Z cray $
 """
 __author__  = "Andrey Orlov,2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49596 $"
+__version__ = "$Revision: 51584 $"
 
 from interfaces import Interface
 from viewletbase import ViewletBase
@@ -24,7 +24,8 @@ class MultiFormItemView(EditView,simple,ViewletBase) :
     generated_form = ViewPageTemplateFile(default_template)
 
     def __init__(self,context,request,*kv,**kw) :
-        fieldNames = getFieldNames(self.schema)
+        #fieldNames = getFieldNames(self.schema)
+        print "~!!!!!", kv, kw, self.fieldNames
         super(simple,self).__init__(context,request,*kv,**kw)
         self._setUpWidgets()
         self.setPrefix(self.prefix)
